<template>
  <div class="bbsl-common-page">
    <div class="bbsl-table-search">
      <el-page-header @back="goBack" :content="this.$route.query.contractName">
      </el-page-header>
    </div>
    <div class="bbsl-table-content">
      <div class="bbsl-btn-content" ref="btnPanel">
        <el-button icon="el-icon-plus" type="primary" @click="handleAdd">添加关联
        </el-button>
        <el-popconfirm title="确定删除选中数据吗？" @confirm="handleDelete">
          <el-button slot="reference" :disabled="!multipleSelection.length" icon="el-icon-delete" type="danger"
            style="margin-left: 10px">删除
          </el-button>
        </el-popconfirm>
      </div>
      <el-table border size="mini" v-loading="loading" ref="multipleSelection" :data="tableData"
        :style="{ width: '100%' }" :max-height="tableMaxHeight" :cell-style="{ 'text-align': 'center' }"
        :header-cell-style="{ 'text-align': 'center' }" @row-dblclick="handleDbClick"
        @selection-change="handleSelectionChange">
        <el-table-column type="selection" width="55"></el-table-column>
        <el-table-column fixed type="index" width="55" label="序号"></el-table-column>
        <el-table-column prop="name" label="设备名称" show-overflow-tooltip></el-table-column>
        <el-table-column prop="typeName" label="产品分类" show-overflow-tooltip></el-table-column>
        <el-table-column prop="productName" label="产品名称" show-overflow-tooltip></el-table-column>
        <el-table-column prop="code" label="设备标识" show-overflow-tooltip></el-table-column>
        <el-table-column prop="managerUserName" label="设备管理人员" show-overflow-tooltip></el-table-column>
        <el-table-column prop="supplierCompanyName" label="供应商" show-overflow-tooltip></el-table-column>
      </el-table>
      <el-pagination align="right" background class="bbsl-pagination" ref="paginationPanel"
        @size-change="handleSizeChange" @current-change="handleCurrentChange" :current-page="queryParam.pageBean.page"
        :page-sizes="[20, 30, 40, 50]" :page-size="queryParam.pageBean.pageSize"
        layout="total, sizes, prev, pager, next, jumper" :total="total"></el-pagination>
    </div>
    <relatedEquimentInfoDialog ref="formModal"></relatedEquimentInfoDialog>
  </div>
</template>
<script>
import { TableMixin } from '@/mixins/tableMixin'
import relationContract from '@/api/device/relationContract.js'
import relatedEquimentInfoDialog from '@/views/Device/resourceManage/components/relatedEquimentInfoDialog.vue'
import dictUtils from '@/components/dict/DictSelectUtils.js'

export default {
  name: 'relatedEquimentDialog',
  components: {
    relatedEquimentInfoDialog
  },
  mixins: [TableMixin],
  data() {
    return {
      parameters: {}, //接收路由参数
      url: {
        delete: '/device/relation/contract/'
      }, // 删除关联信息
      querys: []
    }
  },
  created() {
    this.parameters = this.$route.query
    console.log(this.parameters)
  },
  methods: {
    loadData(page) {
      if (page) {
        this.queryParam.pageBean.page = page
      }
      this.loading = true
      this.tableData = []
      this.queryParam.querys = [
        {
          group: 'main',
          operation: 'EQUAL',
          parentGroup: '',
          property: 'contractId',
          relation: 'AND',
          value: this.parameters.id
        }
      ]
      relationContract.loadContract(this.queryParam, res => {
        this.total = res.total
        this.tableData = res.rows
        this.$set(this.tableData)
        this.loading = false
      })
    },
    goBack() {
      this.$router.go(-1)
    },
    handleAdd() {
      this.$refs.formModal.edit(this.parameters)
    },
    // 重置
    clearQuerys() {
      this.querys[0].value = ''
      this.querys[1].value = ''
    }
  }
}
</script>
<style lang="scss" scoped>
.company-type ::v-deep .el-checkbox-group {
  height: initial !important;
}
</style>
